'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.createApolloClient = createApolloClient;

var _apolloClient = require('apollo-client');

var _apolloClient2 = _interopRequireDefault(_apolloClient);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function createApolloClient(_ref) {
  var initialState = _ref.initialState,
      ssrForceFetchDelay = _ref.ssrForceFetchDelay,
      graphqlUrl = _ref.graphqlUrl,
      loginToken = _ref.loginToken,
      headerLoginTokenKey = _ref.headerLoginTokenKey,
      localStorageLoginTokenKey = _ref.localStorageLoginTokenKey;

  var batchingNetworkInterface = (0, _apolloClient.createBatchingNetworkInterface)({
    uri: graphqlUrl,
    batchInterval: 10,
    opts: {
      credentials: 'same-origin'
    }
  });

  batchingNetworkInterface.use([{
    applyBatchMiddleware: function applyBatchMiddleware(req, next) {
      if (!req.options.headers) {
        req.options.headers = {};
      }

      var localStorageLoginToken = typeof window !== 'undefined' && window.localStorage && window.localStorage.getItem(localStorageLoginTokenKey);

      loginToken = localStorageLoginToken || loginToken;

      req.options.headers[headerLoginTokenKey] = loginToken || null;
      next();
    }
  }]);

  return new _apolloClient2.default({
    ssrMode: typeof window === 'undefined',
    queryDeduplication: true,
    addTypename: true,
    initialState: initialState,
    ssrForceFetchDelay: ssrForceFetchDelay,
    networkInterface: batchingNetworkInterface
  });
}